@@ -69,16 +69,13 @@ def tile_grid_for_epsg(epsg, bbox=None, tile_size=(256, 256), res=None):
 # are not loaded on import time
 class _default_bboxs(object):
     _defaults = {
-        900913: (-20037508.342789244,
-                 -20037508.342789244,
-                  20037508.342789244,
-                  20037508.342789244),
-        3857: (-20037508.342789244,
-               -20037508.342789244,
-                20037508.342789244,
-                20037508.342789244),
         4326: (-180, -90, 180, 90),
     }
+    for epsg_num in (900913, 3857, 102100, 102113):
+        _defaults[epsg_num] = (-20037508.342789244,
+                                -20037508.342789244,
+                                20037508.342789244,
+                                20037508.342789244)
     defaults = None
     def get(self, key, default=None):
         try:
@@ -516,7 +513,7 @@ class TileGrid(object):
         y0 = self.bbox[1] + round(y * res * self.tile_size[1], 12)
         return x0, y0
     
-    def tile_bbox(self, (x, y, z)):
+    def tile_bbox(self, (x, y, z), limit=False):
         """
         Returns the bbox of the given tile.
         
@@ -530,6 +527,13 @@ class TileGrid(object):
         res = self.resolution(z)
         width = round(res * self.tile_size[0], 12)
         height = round(res * self.tile_size[1], 12)
+        if limit:
+            return (
+                max(x0, self.bbox[0]),
+                max(y0, self.bbox[1]),
+                min(x0+width, self.bbox[2]),
+                min(y0+height, self.bbox[3])
+            )
         return (x0, y0, x0+width, y0+height)
     
     def limit_tile(self, tile_coord):
@@ -694,13 +698,11 @@ class MetaGrid(object):
         level = tile_coord[2]
         bbox, buffers = self._meta_bbox(tile_coord)
         grid_size = self._meta_size(level)
-        res = self.grid.resolution(level)
-        width = int((bbox[2] - bbox[0]) / res)
-        height = int((bbox[3] - bbox[1]) / res)
+        size = self._size_from_buffered_bbox(bbox, level)
         
         tile_patterns = self._tiles_pattern(tile=tile_coord, grid_size=grid_size, buffers=buffers)
         
-        return MetaTile(bbox=bbox, size=(width, height), tile_patterns=tile_patterns,
+        return MetaTile(bbox=bbox, size=size, tile_patterns=tile_patterns,
             grid_size=grid_size
         )
     
@@ -715,20 +717,25 @@ class MetaGrid(object):
         bbox, buffers = self._meta_bbox(tiles=bounds)
         
         level = tiles[0][2]
-        res = self.grid.resolution(level)
-        width = int((bbox[2] - bbox[0]) / res)
-        height = int((bbox[3] - bbox[1]) / res)
+        size = self._size_from_buffered_bbox(bbox, level)
         
         tile_pattern = self._tiles_pattern(tiles=tiles, grid_size=grid_size, buffers=buffers)
 
         return MetaTile(
             bbox=bbox,
-            size=(width, height),
+            size=size,
             tile_patterns=tile_pattern,
             grid_size=grid_size,
         )
 
-
+    def _size_from_buffered_bbox(self, bbox, level):
+        # meta_size * tile_size + 2*buffer does not work,
+        # since the buffer can get truncated at the grid border
+        res = self.grid.resolution(level)
+        width = int(round((bbox[2] - bbox[0]) / res))
+        height = int(round((bbox[3] - bbox[1]) / res))
+        return width, height
+    
     def _full_tile_list(self, tiles):
         """
         Return a complete list of all tiles that a minimal meta tile with `tiles` contains.
@@ -768,6 +775,10 @@ class MetaGrid(object):
         
         return x0, y0, z
     
+    def tile_list(self, main_tile):
+        tile_grid = self._meta_size(main_tile[2])
+        return self._meta_tile_list(main_tile, tile_grid)
+    
     def _meta_tile_list(self, main_tile, tile_grid):
         """
         >>> mgrid = MetaGrid(grid=TileGrid(), meta_size=(2, 2))
