@@ -20,7 +20,7 @@ Image and tile manipulation (transforming, merging, etc).
 from __future__ import with_statement
 from cStringIO import StringIO
 
-from mapproxy.platform.image import Image, ImageColor, quantize
+from mapproxy.platform.image import Image, ImageColor, ImageChops, quantize
 from mapproxy.config import base_config
 
 import logging
@@ -72,13 +72,18 @@ class LayerMerger(object):
             img = Image.new('RGBA', size, bgcolor+(0,))
         else:
             img = Image.new('RGB', size, bgcolor)
+        
         for layer in self.layers:
             layer_img = layer.as_image()
-            if layer_img.mode == 'RGBA':
-                # paste w transparency mask from layer
-                img.paste(layer_img, (0, 0), layer_img)
+            if layer.opacity is not None and layer.opacity < 1.0:
+                layer_img = layer_img.convert(img.mode)
+                img = Image.blend(img, layer_img, layer.opacity)
             else:
-                img.paste(layer_img, (0, 0))
+                if layer_img.mode == 'RGBA':
+                    # paste w transparency mask from layer
+                    img.paste(layer_img, (0, 0), layer_img)
+                else:
+                    img.paste(layer_img, (0, 0))
         return ImageSource(img, format)
 
 def merge_images(images, format='png', size=None, transparent=True):
@@ -144,7 +149,7 @@ class ImageSource(object):
     You can access the result as an image (`as_image` ) or a file-like buffer
     object (`as_buffer`).
     """
-    def __init__(self, source, format='png', size=None, transparent=False):
+    def __init__(self, source, format='png', size=None, transparent=False, opacity=None):
         """
         :param source: the image
         :type source: PIL `Image`, image file object, or filename
@@ -157,6 +162,7 @@ class ImageSource(object):
         self.source = source
         self.format = format
         self.transparent = transparent
+        self.opacity = opacity
         self._size = size
     
     def _set_source(self, source):
@@ -253,20 +259,21 @@ class ImageSource(object):
 
     @property
     def size(self):
-        if isinstance(self.source, Image.Image):
-            return self.source.size
-        else:
-            return self._size
+        if self._size is None:
+            self._size = self.as_image().size
+        return self._size
 
 class BlankImageSource(object):
     """
     ImageSource for transparent or solid-color images.
     Implements optimized as_buffer() method.
     """
-    def __init__(self, size, bgcolor=None, transparent=True):
+    def __init__(self, size, bgcolor=None, transparent=True, format=None):
         self.size = size
         self.bgcolor = bgcolor or '#ffffff'
         self.transparent = transparent
+        self.opacity = 0.0 if transparent else 1.0
+        self.format = format
     
     def as_image(self):
         bgcolor = ImageColor.getrgb(self.bgcolor)
@@ -278,7 +285,7 @@ class BlankImageSource(object):
         return img
     
     def as_buffer(self, format=None, paletted=None, seekable=False):
-        return img_to_buf(self.as_image(), format, paletted=False)
+        return img_to_buf(self.as_image(), format or self.format, paletted=False)
 
 class ReadBufWrapper(object):
     """
@@ -366,4 +373,36 @@ def is_single_color_image(image):
         palette = image.getpalette()
         return palette[color*3], palette[color*3+1], palette[color*3+2]
     
-    return result[0][1]
\ No newline at end of file
+    return result[0][1]
+
+def make_transparent(img, color, tolerance=10):
+    """
+    Create alpha channel for the given image and make each pixel
+    in `color` full transparent.
+    
+    Returns an RGBA ImageSoruce.
+    
+    Modifies the image in-place, unless it needs to be converted
+    first (P->RGB).
+    
+    :param color: RGB color tuple
+    :param tolerance: tolerance applied to each color value
+    """
+    result = _make_transparent(img.as_image(), color, tolerance)
+    return ImageSource(result, size=result.size, transparent=True)
+
+def _make_transparent(img, color, tolerance=10):
+    img.load()
+    
+    if img.mode == 'P':
+        img = img.convert('RGB')
+    
+    channels = img.split()
+    mask_channels = []
+    for ch, c in zip(channels, color):
+        low_c, high_c = c-tolerance, c+tolerance
+        mask_channels.append(Image.eval(ch, lambda x: 255 if low_c <= x <= high_c else 0))
+        
+    alpha = reduce(ImageChops.multiply, mask_channels)
+    img.putalpha(ImageChops.invert(alpha))
+    return img
