@@ -65,10 +65,9 @@ def init_libproj():
     libproj.pj_is_latlong.argtypes = [c_void_p]
     libproj.pj_is_latlong.restype = c_int
 
-    libproj.pj_set_searchpath.argtypes = [c_int, POINTER(c_char_p)]
 
     libproj.pj_get_def.argtypes = [c_void_p, c_int]
-    libproj.pj_get_def.restype = c_char_p
+    libproj.pj_get_def.restype = c_void_p
 
     libproj.pj_strerrno.argtypes = [c_int]
     libproj.pj_strerrno.restype = c_char_p
@@ -76,13 +75,18 @@ def init_libproj():
     libproj.pj_get_errno_ref.argtypes = []
     libproj.pj_get_errno_ref.restype = POINTER(c_int)
 
+    # free proj objects
     libproj.pj_free.argtypes = [c_void_p]
+    # free() wrapper
+    libproj.pj_dalloc.argtypes = [c_void_p]
 
     libproj.pj_transform.argtypes = [c_void_p, c_void_p, c_long, c_int,
                                      c_double_p, c_double_p, c_double_p]
     libproj.pj_transform.restype = c_int
-
-    libproj.pj_set_finder.argtypes = [FINDERCMD]
+    
+    if hasattr(libproj, 'pj_set_searchpath'):
+        libproj.pj_set_searchpath.argtypes = [c_int, POINTER(c_char_p)]
+        libproj.pj_set_finder.argtypes = [FINDERCMD]
     
     return libproj
 
@@ -117,17 +121,37 @@ class ProjError(RuntimeError):
 class ProjInitError(ProjError):
     pass
 
-libproj = init_libproj()
 
-if libproj is None and 'MAPPROXY_USE_LIBPROJ' in os.environ:
-    raise ImportError('could not found libproj')
+_use_libproj = _use_pyproj = False
+if 'MAPPROXY_USE_LIBPROJ' in os.environ:
+    _use_libproj = True
 
-if libproj is None or 'MAPPROXY_USE_PYPROJ' in os.environ:
-    try:
-        from pyproj import Proj, transform, set_datapath
-        log.debug('using pyproj for coordinate transformation')
-    except ImportError:
-        raise ImportError('could not found either libproj or pyproj')
+if 'MAPPROXY_USE_PYPROJ' in os.environ:
+    _use_pyproj = True
+
+if not _use_libproj and not _use_pyproj:
+    _use_libproj = True # Default
+    _use_pyproj = True # Fallback
+
+libproj = None
+
+if _use_libproj:
+    libproj = init_libproj()
+
+if libproj is None:
+    if _use_pyproj:
+        try:
+            from pyproj import Proj, transform, set_datapath
+            Proj, transform, set_datapath #prevent pyflakes arnings
+            log.debug('using pyproj for coordinate transformation')
+        except ImportError:
+            if _use_libproj:
+                raise ImportError('could not found either libproj or pyproj')
+            else:
+                raise ImportError('could not found pyproj')
+            
+    else:
+        raise ImportError('could not found libproj')
 else:
     log.debug('using libproj for coordinate transformation')
 
@@ -150,6 +174,9 @@ else:
                 errno = libproj.pj_get_errno_ref().contents
                 raise ProjInitError('error initializing Proj(proj_def=%r, init=%r): %s' %
                     (proj_def, init, libproj.pj_strerrno(errno)))
+            
+            self.srs = self._srs()
+            self._latlong = bool(libproj.pj_is_latlong(self._proj))
     
         def is_latlong(self):
             """
@@ -164,14 +191,13 @@ else:
             ...      '+nadgrids=@null +no_defs').is_latlong()
             False
             """
-            if libproj.pj_is_latlong(self._proj):
-                return True
-            else:
-                return False
-    
-        @property
-        def srs(self):
-            return libproj.pj_get_def(self._proj, 0)
+            return self._latlong
+        
+        def _srs(self):
+            res = libproj.pj_get_def(self._proj, 0)
+            srs_def = ctypes.c_char_p(res).value
+            libproj.pj_dalloc(res)
+            return srs_def
     
         def __del__(self):
             if self._proj and libproj:
@@ -235,4 +261,4 @@ if __name__ == '__main__':
     coords = transform(prj1, prj2, *coords)
     print coords
     coords = transform(prj2, prj1, *coords)
-    print coords
\ No newline at end of file
+    print coords
