@@ -1,5 +1,5 @@
 # This file is part of the MapProxy project.
-# Copyright (C) 2010 Omniscale <http://omniscale.de>
+# Copyright (C) 2010, 2011 Omniscale <http://omniscale.de>
 # 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -47,19 +47,30 @@ class TileFilter(object):
     def create_filter(self, layer_conf):
         return NotImplementedError
 
-def watermark_filter(text, opacity=None, font_size=None):
+def watermark_filter(text, opacity=None, spacing=None, font_size=None):
     """
     Returns a tile filter that adds a watermark to the tiles.
     :param text: watermark text
     """
     def _watermark_filter(tile):
-        odd = False if tile.coord[1] % 2 == 0 else True
-        wimg = WatermarkImage(text, format=tile.source.format, odd=odd,
+        placement = tile_watermark_placement(tile.coord, spacing == 'wide')
+        wimg = WatermarkImage(text, format=tile.source.format, placement=placement,
                               opacity=opacity, font_size=font_size)
         tile.source = wimg.draw(img=tile.source)
         return tile
     return _watermark_filter
 
+def tile_watermark_placement(coord, double_spacing=False):
+    if not double_spacing:
+        if coord[1] % 2 == 0:
+            return 'c'
+        else:
+            return 'b'
+    
+    if coord[1] % 2 != coord[0] % 2:
+        return 'c'
+
+    return None
 
 class WaterMarkTileFilter(TileFilter):
     """
@@ -75,10 +86,14 @@ class WaterMarkTileFilter(TileFilter):
     def create_filter(self, conf, context, **kw):
         if 'watermark' in conf:
             text = conf['watermark'].get('text', '')
-            opacity = conf['watermark'].get('opacity', None)
-            font_size = conf['watermark'].get('font_size', None)
+            opacity = conf['watermark'].get('opacity')
+            font_size = conf['watermark'].get('font_size')
+            spacing = conf['watermark'].get('spacing')
+            if spacing not in ('wide', None):
+                raise ValueError('unsupported watermark spacing: %r' % spacing)
             if text != '':
-                return watermark_filter(text, opacity=opacity, font_size=font_size)
+                return watermark_filter(text, opacity=opacity, font_size=font_size,
+                                        spacing=spacing)
 
 class PNGQuantFilter(object):
     def __init__(self):
